@@ -28,7 +28,6 @@
 #include <QtGui/QListView>
 #include <QDBusConnection>
 #include <QDBusInterface>
-#include <QDebug>
 
 #include <KServiceTypeTrader>
 #include <KPluginInfo>
@@ -38,6 +37,7 @@
 #include "ui_kcm.h"
 #include "libkdeconnect/dbusinterfaces.h"
 #include "devicessortproxymodel.h"
+#include "kdebugnamespace.h"
 
 K_PLUGIN_FACTORY(KdeConnectKcmFactory, registerPlugin<KdeConnectKcm>();)
 K_EXPORT_PLUGIN(KdeConnectKcmFactory("kdeconnect-kcm", "kdeconnect-kcm"))
@@ -134,7 +134,6 @@ void KdeConnectKcm::deviceSelected(const QModelIndex& current)
         }
     }
 
-
     //FIXME: KPluginSelector has no way to remove a list of plugins and load another, so we need to destroy and recreate it each time
     delete kcmUi->pluginSelector;
     kcmUi->pluginSelector = new KPluginSelector(this);
