@@ -1,5 +1,7 @@
 #include "device.h"
 
+#include <QDBusConnection>
+
 #include <KSharedConfig>
 #include <KConfigGroup>
 #include <KStandardDirs>
@@ -8,9 +10,7 @@
 #include <KNotification>
 #include <KIcon>
 
-#include <QDBusConnection>
-#include <QDebug>
-
+#include "kdebugnamespace.h"
 #include "plugins/kdeconnectplugin.h"
 #include "plugins/pluginloader.h"
 #include "backends/devicelink.h"
@@ -25,9 +25,10 @@ Device::Device(const QString& id)
     KSharedConfigPtr config = KSharedConfig::openConfig("kdeconnectrc");
     KConfigGroup data = config->group("trusted_devices").group(id);
 
-    m_deviceName = data.readEntry<QString>("deviceName", QString("unnamed"));
+    m_deviceName = data.readEntry<QString>("deviceName", QLatin1String("unnamed"));
+    m_deviceType = str2type(data.readEntry<QString>("deviceType", QLatin1String("unknown")));
 
-    const QString& key = data.readEntry<QString>("publicKey",QString());
+    const QString& key = data.readEntry<QString>("publicKey", QString());
     m_publicKey = QCA::RSAPublicKey::fromPEM(key);
 
     //Register in bus
@@ -38,6 +39,7 @@ Device::Device(const QString& id)
 Device::Device(const NetworkPackage& identityPackage, DeviceLink* dl)
     : m_deviceId(identityPackage.get<QString>("deviceId"))
     , m_deviceName(identityPackage.get<QString>("deviceName"))
+    , m_deviceType(str2type(identityPackage.get<QString>("deviceType")))
     , m_pairStatus(Device::NotPaired)
     , m_protocolVersion(identityPackage.get<int>("protocolVersion"))
 {
@@ -133,12 +135,7 @@ void Device::requestPair()
     m_pairStatus = Device::Requested;
 
     //Send our own public key
-    NetworkPackage np(PACKAGE_TYPE_PAIR);
-    np.set("pair", true);
-    KSharedConfigPtr config = KSharedConfig::openConfig("kdeconnectrc");
-    const QString& key = config->group("myself").readEntry<QString>("publicKey",QString());
-    np.set("publicKey",key);
-    bool success = sendPackage(np);
+    bool success = sendOwnPublicKey();
 
     if (!success) {
         m_pairStatus = Device::NotPaired;
@@ -189,7 +186,7 @@ static bool lessThan(DeviceLink* p1, DeviceLink* p2)
 
 void Device::addLink(const NetworkPackage& identityPackage, DeviceLink* link)
 {
-    //qDebug() << "Adding link to" << id() << "via" << link->provider();
+    //kDebug(kdeconnect_kded()) << "Adding link to" << id() << "via" << link->provider();
 
     m_protocolVersion = identityPackage.get<int>("protocolVersion");
     if (m_protocolVersion != NetworkPackage::ProtocolVersion) {
@@ -203,10 +200,11 @@ void Device::addLink(const NetworkPackage& identityPackage, DeviceLink* link)
 
     //re-read the device name from the identityPackage because it could have changed
     m_deviceName = identityPackage.get<QString>("deviceName");
+    m_deviceType = str2type(identityPackage.get<QString>("deviceType"));
 
-    //TODO: Do not read the key every time
+    //TODO: Do not read the key every time from config, store somewhere
     KSharedConfigPtr config = KSharedConfig::openConfig("kdeconnectrc");
-    const QString& key = config->group("myself").readEntry<QString>("privateKey",QString());
+    const QString& key = config->group("myself").readEntry<QString>("privateKey", QString());
     QCA::PrivateKey privateKey = QCA::PrivateKey::fromPEM(key);
     link->setPrivateKey(privateKey);
 
@@ -238,7 +236,7 @@ void Device::removeLink(DeviceLink* link)
 {
     m_deviceLinks.removeOne(link);
 
-    //qDebug() << "RemoveLink" << m_deviceLinks.size() << "links remaining";
+    //kDebug(kdeconnect_kded()) << "RemoveLink" << m_deviceLinks.size() << "links remaining";
 
     if (m_deviceLinks.isEmpty()) {
         reloadPlugins();
@@ -266,12 +264,12 @@ void Device::privateReceivedPackage(const NetworkPackage& np)
 {
     if (np.type() == PACKAGE_TYPE_PAIR) {
 
-        //qDebug() << "Pair package";
+        //kDebug(kdeconnect_kded()) << "Pair package";
 
         bool wantsPair = np.get<bool>("pair");
 
         if (wantsPair == isPaired()) {
-            qDebug() << "Already" << (wantsPair? "paired":"unpaired");
+            kDebug(kdeconnect_kded()) << "Already" << (wantsPair? "paired":"unpaired");
             if (m_pairStatus == Device::Requested) {
                 m_pairStatus = Device::NotPaired;
                 pairingTimer.stop();
@@ -286,7 +284,7 @@ void Device::privateReceivedPackage(const NetworkPackage& np)
             const QString& key = np.get<QString>("publicKey");
             m_publicKey = QCA::RSAPublicKey::fromPEM(key);
             if (m_publicKey.isNull()) {
-                qDebug() << "ERROR decoding key";
+                kDebug(kdeconnect_kded()) << "ERROR decoding key";
                 if (m_pairStatus == Device::Requested) {
                     m_pairStatus = Device::NotPaired;
                     pairingTimer.stop();
@@ -297,23 +295,12 @@ void Device::privateReceivedPackage(const NetworkPackage& np)
 
             if (m_pairStatus == Device::Requested)  { //We started pairing
 
-                qDebug() << "Pair answer";
-
-                m_pairStatus = Device::Paired;
-                pairingTimer.stop();
-
-                //Store as trusted device
-                KSharedConfigPtr config = KSharedConfig::openConfig("kdeconnectrc");
-                config->group("trusted_devices").group(id()).writeEntry("publicKey",key);
-                config->group("trusted_devices").group(id()).writeEntry("deviceName",name());
-
-                reloadPlugins();
-
-                Q_EMIT pairingSuccesful();
+                kDebug(kdeconnect_kded()) << "Pair answer";
+                setAsPaired();
 
             } else {
 
-                qDebug() << "Pair request";
+                kDebug(kdeconnect_kded()) << "Pair request";
 
                 KNotification* notification = new KNotification("pingReceived"); //KNotification::Persistent
                 notification->setPixmap(KIcon("dialog-information").pixmap(48, 48));
@@ -331,7 +318,7 @@ void Device::privateReceivedPackage(const NetworkPackage& np)
 
         } else {
 
-            qDebug() << "Unpair request";
+            kDebug(kdeconnect_kded()) << "Unpair request";
 
             if (m_pairStatus == Device::Requested) {
                 pairingTimer.stop();
@@ -354,44 +341,25 @@ void Device::privateReceivedPackage(const NetworkPackage& np)
         }
     } else {
         //TODO: Notify the other side that we don't trust them
-        qDebug() << "device" << name() << "not paired, ignoring package" << np.type();
+        kDebug(kdeconnect_kded()) << "device" << name() << "not paired, ignoring package" << np.type();
     }
 
 }
 
-void Device::acceptPairing()
+bool Device::sendOwnPublicKey()
 {
-    if (m_pairStatus != Device::RequestedByPeer) return;
-
-    qDebug() << "Accepted pairing";
-
-    KSharedConfigPtr config = KSharedConfig::openConfig("kdeconnectrc");
-
-    //Send our own public key
     NetworkPackage np(PACKAGE_TYPE_PAIR);
     np.set("pair", true);
-    const QString& key = config->group("myself").readEntry<QString>("publicKey",QString());
+    KSharedConfigPtr config = KSharedConfig::openConfig("kdeconnectrc");
+    const QString& key = config->group("myself").readEntry<QString>("publicKey", QString());
     np.set("publicKey",key);
     bool success = sendPackage(np);
-
-    if (!success) {
-        return;
-    }
-
-    //Store as trusted device
-    config->group("trusted_devices").group(id()).writeEntry("publicKey", m_publicKey.toPEM());
-    config->group("trusted_devices").group(id()).writeEntry("deviceName", name());
-
-    m_pairStatus = Device::Paired;
-
-    reloadPlugins(); //This will load plugins
-
-    Q_EMIT pairingSuccesful();
+    return success;
 }
 
 void Device::rejectPairing()
 {
-    qDebug() << "Rejected pairing";
+    kDebug(kdeconnect_kded()) << "Rejected pairing";
 
     m_pairStatus = Device::NotPaired;
 
@@ -403,6 +371,46 @@ void Device::rejectPairing()
 
 }
 
+void Device::acceptPairing()
+{
+    if (m_pairStatus != Device::RequestedByPeer) return;
+
+    kDebug(kdeconnect_kded()) << "Accepted pairing";
+
+    bool success = sendOwnPublicKey();
+
+    if (!success) {
+        m_pairStatus = Device::NotPaired;
+        return;
+    }
+
+    setAsPaired();
+
+}
+
+void Device::setAsPaired()
+{
+
+    m_pairStatus = Device::Paired;
+
+    pairingTimer.stop(); //Just in case it was started
+
+    storeAsTrusted(); //Save to the config as trusted
+
+    reloadPlugins(); //Will actually load the plugins
+
+    Q_EMIT pairingSuccesful();
+
+}
+
+void Device::storeAsTrusted()
+{
+    KSharedConfigPtr config = KSharedConfig::openConfig("kdeconnectrc");
+    config->group("trusted_devices").group(id()).writeEntry("publicKey", m_publicKey.toPEM());
+    config->group("trusted_devices").group(id()).writeEntry("deviceName", name());
+    config->group("trusted_devices").group(id()).writeEntry("deviceType", type2str(m_deviceType));
+}
+
 QStringList Device::availableLinks() const
 {
     QStringList sl;
@@ -416,6 +424,21 @@ void Device::sendPing()
 {
     NetworkPackage np(PACKAGE_TYPE_PING);
     bool success = sendPackage(np);
-    qDebug() << "sendPing:" << success;
+    kDebug(kdeconnect_kded()) << "sendPing:" << success;
 }
 
+Device::DeviceType Device::str2type(QString deviceType) {
+    if (deviceType == "desktop") return Desktop;
+    if (deviceType == "laptop") return Laptop;
+    if (deviceType == "phone") return Phone;
+    if (deviceType == "tablet") return Tablet;
+    return Unknown;
+}
+
+QString Device::type2str(Device::DeviceType deviceType) {
+    if (deviceType == Desktop) return "desktop";
+    if (deviceType == Laptop) return "laptop";
+    if (deviceType == Phone) return "phone";
+    if (deviceType == Tablet) return "tablet";
+    return "unknown";
+}
\ No newline at end of file
