@@ -20,7 +20,7 @@
 
 #include "batterydbusinterface.h"
 
-#include <QDebug>
+#include "../../kdebugnamespace.h"
 
 BatteryDbusInterface::BatteryDbusInterface(QObject *parent)
     : QDBusAbstractAdaptor(parent)
@@ -29,7 +29,7 @@ BatteryDbusInterface::BatteryDbusInterface(QObject *parent)
 
 BatteryDbusInterface::~BatteryDbusInterface()
 {
-    qDebug() << "Destroying BatteryDbusInterface";
+    kDebug(kdeconnect_kded()) << "Destroying BatteryDbusInterface";
 }
 
 void BatteryDbusInterface::updateValues(bool isCharging, int currentCharge)
