@@ -21,12 +21,10 @@
 #ifndef BATTERYPLUGIN_H
 #define BATTERYPLUGIN_H
 
-#include <QDBusAbstractAdaptor>
-
-#include <KNotification>
-
 #include "../kdeconnectplugin.h"
 
+#define PACKAGE_TYPE_BATTERY QLatin1String("kdeconnect.battery")
+
 class BatteryDbusInterface;
 
 class BatteryPlugin
