@@ -20,24 +20,24 @@
 
 #include "pingplugin.h"
 
-#include <QDebug>
-
 #include <KNotification>
 #include <KIcon>
 #include <KLocalizedString>
 
+#include "../../kdebugnamespace.h"
+
 K_PLUGIN_FACTORY( KdeConnectPluginFactory, registerPlugin< PingPlugin >(); )
 K_EXPORT_PLUGIN( KdeConnectPluginFactory("kdeconnect_ping", "kdeconnect_ping") )
 
 PingPlugin::PingPlugin(QObject* parent, const QVariantList& args)
     : KdeConnectPlugin(parent, args)
 {
-    //qDebug() << "Ping plugin constructor for device" << device()->name();
+    //kDebug(kdeconnect_kded()) << "Ping plugin constructor for device" << device()->name();
 }
 
 PingPlugin::~PingPlugin()
 {
-    //qDebug() << "Ping plugin destructor for device" << device()->name();
+    //kDebug(kdeconnect_kded()) << "Ping plugin destructor for device" << device()->name();
 }
 
 bool PingPlugin::receivePackage(const NetworkPackage& np)
